@@ -1,7 +1,7 @@
 /*
     Qalculate    
 
-    Copyright (C) 2003-2006  Niklas Knutsson (nq@altern.org)
+    Copyright (C) 2003-2007  Niklas Knutsson (nq@altern.org)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,10 +38,13 @@ enum {
 	QALCULATE_HISTORY_TRANSFORMATION,
 	QALCULATE_HISTORY_RESULT,
 	QALCULATE_HISTORY_RESULT_APPROXIMATE,
+	QALCULATE_HISTORY_PARSE_WITHEQUALS,
 	QALCULATE_HISTORY_PARSE,
+	QALCULATE_HISTORY_PARSE_APPROXIMATE,
 	QALCULATE_HISTORY_WARNING,
 	QALCULATE_HISTORY_ERROR,
-	QALCULATE_HISTORY_OLD
+	QALCULATE_HISTORY_OLD,
+	QALCULATE_HISTORY_REGISTER_MOVED
 };
 
 bool can_display_unicode_string_function(const char *str, void *w);
@@ -367,6 +370,7 @@ void on_menu_item_assumptions_nonpositive_activate(GtkMenuItem *w, gpointer user
 void on_menu_item_assumptions_unknown_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_assume_nonzero_denominators_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_normal_activate(GtkMenuItem *w, gpointer user_data);
+void on_popup_menu_item_display_engineering_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_purely_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_display_non_scientific_activate(GtkMenuItem *w, gpointer user_data);
@@ -389,10 +393,16 @@ void on_popup_menu_item_denominator_prefixes_activate(GtkMenuItem *w, gpointer u
 void on_popup_menu_item_view_matrix_activate(GtkMenuItem *w, gpointer user_data);
 void on_popup_menu_item_view_vector_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_display_normal_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_display_engineering_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_display_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_display_purely_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_display_non_scientific_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_display_prefixes_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_indicate_infinite_series_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_show_ending_zeroes_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_round_halfway_to_even_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_negative_exponents_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_sort_minus_last_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_fraction_decimal_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_fraction_decimal_exact_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_fraction_combined_activate(GtkMenuItem *w, gpointer user_data);
